Crate walletkit

Crate walletkit 

WalletKit is the reference implementation for World ID clients.

It provides the Rust API and UniFFI bindings used by mobile applications to interact with World ID. The public API is re-exported from walletkit_core.

Modules

authenticator
The Authenticator is the main component with which users interact with the World ID Protocol.
defaults
Default configuration values for each Environment.
error
Contains error outputs from WalletKit
flamingo
Attested Flamingo matching in preparation for zero-knowledge proof generation. Attested Flamingo matching in preparation for zero-knowledge proof generation.
issuers
Credential issuers for World ID (NFC, etc.) Logic for different specific issuers of Credentials in World ID.
logger
Contains logging functionality that can be integrated with foreign language bindings.
proof_request_credential_constraints_check
Pre-flight check of whether stored credentials can satisfy a requests::ProofRequest. Pre-flight check of whether the credential store can satisfy a proof request.
requests
Proof requests and responses in World ID v4.
storage
Credential storage primitives for World ID v4.
user_agent
User agent for HTTP requests. User agent for HTTP requests.

Structs

Authenticator
The Authenticator is the main component with which users interact with the World ID Protocol.
Credential
A wrapper around CoreCredential to enable FFI interoperability.
FieldElement
A wrapper around FieldElement to enable FFI interoperability.
InitializingAuthenticator
Represents an Authenticator in the process of being initialized.
OwnershipProof
A WIP-103 Ownership Proof available to foreign bindings
RecoveryData
Identity material derived from a seed for use during account recovery.
RecoveryUpdateSignature
The signature and signing nonce returned by Authenticator::danger_sign_initiate_recovery_agent_update.
UserAgent
Represents a User-Agent string.
UserAgentBuilder
Builds the UserAgent string sent as the HTTP User-Agent header.

Enums

Environment
Represents the environment in which a World ID is being presented and used.
GatewayRequestStatus
Status of an account operation submitted through the gateway.
Region
Region for node selection.
RegistrationStatus
Registration status for a World ID being created through the gateway.