Module defaults

Module defaults 

Default configuration values for each Environment.

Statics

POH_RECOVERY_AGENT_ADDRESS_PRODUCTION
The PoH Recovery Agent contract address on the production environment.
POH_RECOVERY_AGENT_ADDRESS_STAGING
The PoH Recovery Agent contract address on the staging environment.
STAGING_WORLD_ID_REGISTRY
The Staging World ID Registry contract address also on World Chain Mainnet.
WORLD_ID_REGISTRY
The World ID Registry contract address on World Chain Mainnet.
WORLD_ID_VERIFIER_PRODUCTION
The WorldIDVerifier proxy contract address on the production environment (World Chain Mainnet, chain 480).
WORLD_ID_VERIFIER_STAGING
The WorldIDVerifier proxy contract address on the staging environment (World Chain Mainnet, chain 480).

Functions

default_config
Builds a Config for the given Environment using direct (non-OHTTP) service endpoints — the default for SDK consumers.
default_config_with_ohttp
Builds a Config for the given Environment using OHTTP endpoints.
world_id_verifier_address
Returns the WorldIDVerifier proxy contract address for the given environment.